# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Information utility module for flets azukeru.

Define class for information about backup, data copy and so on.
"""


from iobase.xmldata import (XmlNode)
from ionas.backupsync.info import (ConnectionInfo, TargetInfo,)

from pkgaddon.flets_azukeru_config import (HOST_NAME_KEY,
                                            USING_IMAGE_LOGIN_KEY,
                                            COMPANY_ID_KEY,
                                            SERVICE_ID_KEY,
                                            DESTINATION_INFO_MAP)


NAME_NAME = "name"
ID_NAME = "id"
CONTRACTOR_NAME = "contractor"
PLAN_NAME = "plan"
AUTHMETHOD_NAME = "authmethod"
OTHERAUTHMETHOD_NAME = "otherauthmethod"
TERMINALKEY_NAME = "terminalkey"
CLIENTID_NAME = "clientid"
PASSWORD_NAME = "password"
TYPE_NAME = "type"
FOLDER_NAME = "folder"
SUBDIR_NAME = "subdir"

DESTINATION_KEY = "destination"
IS_AUTH_KEY = "is_auth"
IS_OTHER_KEY = "is_other"

TO_DESTINATION_MAP = {
        "east": {
                IS_AUTH_KEY: False,
                "azukeru" : {
                        DESTINATION_KEY: "east",
                    },
                "azukeru_pro" : {
                        "east_line_auth": "pro_east_line_auth",
                        "west_line_auth": "pro_west_line_auth",
                        "terminal_auth": "pro_terminal_auth",
                    },
                "azukeru_aio" : {
                        DESTINATION_KEY: "pro_aio_terminal_auth",
                    },
            },
        "west": {
                DESTINATION_KEY: "west",
            },
        "other": {
                IS_AUTH_KEY: True,
                IS_OTHER_KEY: True,
                "line_auth" : "pro_oem_line_auth",
                "terminal_auth" : "pro_oem_terminal_auth",
            },
    }


class FletsAzukeruConnectionInfo(ConnectionInfo):
    """Class for flets azukeru connection information."""

    def _get_destination(self, contractor, plan, authmethod, otherauthmethod):
        """Return destination."""

        if DESTINATION_KEY in TO_DESTINATION_MAP[contractor]:
            return TO_DESTINATION_MAP[contractor][DESTINATION_KEY]

        if TO_DESTINATION_MAP[contractor].get(IS_AUTH_KEY, False):
            if TO_DESTINATION_MAP[contractor].get(IS_OTHER_KEY, False):
                return TO_DESTINATION_MAP[contractor][otherauthmethod]
            else:
                return TO_DESTINATION_MAP[contractor][authmethod]

        if DESTINATION_KEY in TO_DESTINATION_MAP[contractor][plan]:
            return TO_DESTINATION_MAP[contractor][plan][DESTINATION_KEY]

        if TO_DESTINATION_MAP[contractor][plan].get(IS_OTHER_KEY, False):
            return TO_DESTINATION_MAP[contractor][plan][otherauthmethod]
        else:
            return TO_DESTINATION_MAP[contractor][plan][authmethod]

    def __init__(self, connection_xml):
        """Constructor."""

        super(FletsAzukeruConnectionInfo, self).__init__(
                                    connection_xml.get_value(NAME_NAME))

        self.id = connection_xml.get_value(ID_NAME, "")
        self.contractor = connection_xml.get_value(CONTRACTOR_NAME, "")
        self.plan = connection_xml.get_value(PLAN_NAME, "")
        self.authmethod = connection_xml.get_value(AUTHMETHOD_NAME, "")
        self.otherauthmethod = \
                connection_xml.get_value(OTHERAUTHMETHOD_NAME, "")
        self.terminalkey = connection_xml.get_value(TERMINALKEY_NAME, "")
        self.clientid = connection_xml.get_value(CLIENTID_NAME, "")
        self.password = connection_xml.get_value(PASSWORD_NAME, "")

        self.destination = self._get_destination(self.contractor, self.plan,
                                        self.authmethod, self.otherauthmethod)

        destination_info = DESTINATION_INFO_MAP[self.destination]
        self.host_name = destination_info[HOST_NAME_KEY]
        self.using_image_login = destination_info[USING_IMAGE_LOGIN_KEY]
        self.company_id = destination_info[COMPANY_ID_KEY]
        self.service_id = destination_info[SERVICE_ID_KEY]


class FletsAzukeruTargetInfo(TargetInfo):
    """Class for flets azukeru target information."""

    MY_FOLDER = "my"
    GROUP_FOLDER = "group"

    def __init__(self, target_xml, connection_xml):
        """Constructor."""

        super(FletsAzukeruTargetInfo, self).__init__(
                                target_xml.get_value(TYPE_NAME),
                                FletsAzukeruConnectionInfo(connection_xml))

        self.folder = target_xml.get_value(FOLDER_NAME, self.MY_FOLDER)
        self.subdir = target_xml.get_value(SUBDIR_NAME, "")

    def get_root_path(self):
        return u"/"

    def get_target_name(self):
        target_name = "fletsazukeru_" + self.connection_info.name
        if isinstance(target_name, str):
            target_name = target_name.decode("UTF8")

        return target_name

    def do_wait_modified(self):
        return False
